==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/zh_CN.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "丢失的回复密钥",
    "Please repeat the recovery key password" : "请替换恢复密钥",
    "Repeated recovery key password does not match the provided recovery key password" : "重复的恢复密钥密码与提供的恢复密钥密码不匹配",
    "Recovery key successfully enabled" : "恢复密钥成功启用",
    "Could not enable recovery key. Please check your recovery key password!" : "不能启用恢复密钥。请检查恢复密钥密码！",
    "Recovery key successfully disabled" : "恢复密钥成功禁用",
    "Could not disable recovery key. Please check your recovery key password!" : "不能禁用恢复密钥。请检查恢复密钥密码！",
    "Missing parameters" : "缺少参数",
    "Please provide the old recovery password" : "请提供原来的恢复密码",
    "Please provide a new recovery password" : "请提供一个新的恢复密码",
    "Please repeat the new recovery password" : "请替换新的恢复密码",
    "Password successfully changed." : "密码修改成功。",
    "Could not change the password. Maybe the old password was not correct." : "不能修改密码。旧密码可能不正确。",
    "Recovery Key disabled" : "恢复密钥已禁用",
    "Recovery Key enabled" : "恢复密钥已启用",
    "Could not enable the recovery key, please try again or contact your administrator" : "无法启用恢复密钥，请重试或联系您的管理员",
    "Could not update the private key password." : "不能更新私有密钥。",
    "The old password was not correct, please try again." : "原始密码错误，请重试。",
    "The current log-in password was not correct, please try again." : "当前登录密码不正确，请重试。",
    "Private key password successfully updated." : "私钥密码成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "无效的加密应用程序私钥。请在您的个人设置中更新您的私钥密码，以恢复对加密文件的访问。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "加密应用被启用了，但是您的加密密钥没有初始化。请重新登出登录系统一次。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "请启用管理员设置中的服务端加密，以使用加密模块。",
    "Encryption app is enabled and ready" : "加密应用程序已启用并准备就绪",
    "Bad Signature" : "签名已损坏",
    "Missing Signature" : "签名已丢失",
    "one-time password for server-side-encryption" : "用于服务端加密的一次性密码",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "请登录网络界面，进入个人设置的 \"安全\" 部分，在“旧登录密码”字段中输入此密码，并在当前登录密码中输入该密码，以更新您的加密密码。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "无法解密此文件，可能这是一个共享文件。请通知文件所有者与你重新共享该文件。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "无法读取此文件，可能这是一个共享文件。请通知文件所有者与你重新共享该文件。",
    "Default encryption module" : "默认加密模块",
    "Default encryption module for server-side encryption" : "服务端加密的默认加密模块",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "加密应用已启用，但您的密钥未初始化，请登出并再次登录",
    "Encrypt the home storage" : "加密主目录储存",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "启用此选项将加密存储在主存储上的所有文件，否则只会加密外部存储上的文件",
    "Enable recovery key" : "启用恢复密钥",
    "Disable recovery key" : "禁用恢复密钥",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "恢复密钥是用于加密文件的附加加密密钥。如果忘记密码，可以使用该密钥从帐户中恢复文件。",
    "Recovery key password" : "恢复密钥密码",
    "Repeat recovery key password" : "重复恢复密码",
    "Change recovery key password:" : "更改恢复密钥密码：",
    "Old recovery key password" : "旧的恢复密码",
    "New recovery key password" : "新恢复密码",
    "Repeat new recovery key password" : "重复新的恢复密码",
    "Change Password" : "修改密码",
    "Basic encryption module" : "基础加密模块",
    "Your private key password no longer matches your log-in password." : "您的私钥不再与您的登录密码匹配。",
    "Set your old private key password to your current log-in password:" : "将的私钥设置为当前登录密码：",
    "Old log-in password" : "旧登录密码",
    "Current log-in password" : "当前登录密码",
    "Update Private Key Password" : "更新私钥密码",
    "Enable password recovery:" : "启用密码恢复：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "启用该项将允许您在密码丢失后取回您的加密文件",
    "Enabled" : "启用",
    "Disabled" : "禁用"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/encryption/l10n/zh_CN.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "丢失的回复密钥",
    "Please repeat the recovery key password" : "请替换恢复密钥",
    "Repeated recovery key password does not match the provided recovery key password" : "重复的恢复密钥密码与提供的恢复密钥密码不匹配",
    "Recovery key successfully enabled" : "恢复密钥成功启用",
    "Could not enable recovery key. Please check your recovery key password!" : "不能启用恢复密钥。请检查恢复密钥密码！",
    "Recovery key successfully disabled" : "恢复密钥成功禁用",
    "Could not disable recovery key. Please check your recovery key password!" : "不能禁用恢复密钥。请检查恢复密钥密码！",
    "Missing parameters" : "缺少参数",
    "Please provide the old recovery password" : "请提供原来的恢复密码",
    "Please provide a new recovery password" : "请提供一个新的恢复密码",
    "Please repeat the new recovery password" : "请替换新的恢复密码",
    "Password successfully changed." : "密码修改成功。",
    "Could not change the password. Maybe the old password was not correct." : "不能修改密码。旧密码可能不正确。",
    "Recovery Key disabled" : "恢复密钥已禁用",
    "Recovery Key enabled" : "恢复密钥已启用",
    "Could not enable the recovery key, please try again or contact your administrator" : "无法启用恢复密钥，请重试或联系您的管理员",
    "Could not update the private key password." : "不能更新私有密钥。",
    "The old password was not correct, please try again." : "原始密码错误，请重试。",
    "The current log-in password was not correct, please try again." : "当前登录密码不正确，请重试。",
    "Private key password successfully updated." : "私钥密码成功更新。",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "无效的加密应用程序私钥。请在您的个人设置中更新您的私钥密码，以恢复对加密文件的访问。",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "加密应用被启用了，但是您的加密密钥没有初始化。请重新登出登录系统一次。",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "请启用管理员设置中的服务端加密，以使用加密模块。",
    "Encryption app is enabled and ready" : "加密应用程序已启用并准备就绪",
    "Bad Signature" : "签名已损坏",
    "Missing Signature" : "签名已丢失",
    "one-time password for server-side-encryption" : "用于服务端加密的一次性密码",
    "Encryption password" : "加密密码",
    "The administration enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>." : "服务器端加密已启用，您的文件已经使用密码<strong>%s</strong>加密。",
    "The administration enabled server-side-encryption. Your files were encrypted using the password \"%s\"." : "服务器端加密已启用，您的文件已经使用密码“%s”加密。",
    "Please login to the web interface, go to the \"Security\" section of your personal settings and update your encryption password by entering this password into the \"Old login password\" field and your current login password." : "请登录网络界面，进入个人设置的 \"安全\" 部分，在“旧登录密码”字段中输入此密码，并在当前登录密码中输入该密码，以更新您的加密密码。",
    "Cannot decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "无法解密此文件，可能这是一个共享文件。请通知文件所有者与你重新共享该文件。",
    "Cannot read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "无法读取此文件，可能这是一个共享文件。请通知文件所有者与你重新共享该文件。",
    "Default encryption module" : "默认加密模块",
    "Default encryption module for server-side encryption" : "服务端加密的默认加密模块",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "加密应用已启用，但您的密钥未初始化，请登出并再次登录",
    "Encrypt the home storage" : "加密主目录储存",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "启用此选项将加密存储在主存储上的所有文件，否则只会加密外部存储上的文件",
    "Enable recovery key" : "启用恢复密钥",
    "Disable recovery key" : "禁用恢复密钥",
    "The recovery key is an additional encryption key used to encrypt files. It is used to recover files from an account if the password is forgotten." : "恢复密钥是用于加密文件的附加加密密钥。如果忘记密码，可以使用该密钥从帐户中恢复文件。",
    "Recovery key password" : "恢复密钥密码",
    "Repeat recovery key password" : "重复恢复密码",
    "Change recovery key password:" : "更改恢复密钥密码：",
    "Old recovery key password" : "旧的恢复密码",
    "New recovery key password" : "新恢复密码",
    "Repeat new recovery key password" : "重复新的恢复密码",
    "Change Password" : "修改密码",
    "Basic encryption module" : "基础加密模块",
    "Your private key password no longer matches your log-in password." : "您的私钥不再与您的登录密码匹配。",
    "Set your old private key password to your current log-in password:" : "将的私钥设置为当前登录密码：",
    "Old log-in password" : "旧登录密码",
    "Current log-in password" : "当前登录密码",
    "Update Private Key Password" : "更新私钥密码",
    "Enable password recovery:" : "启用密码恢复：",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "启用该项将允许您在密码丢失后取回您的加密文件",
    "Enabled" : "启用",
    "Disabled" : "禁用"
},
"nplurals=1; plural=0;");
